@@ -1,5 +1,5 @@
 package App::bmkpasswd;
-$App::bmkpasswd::VERSION = '2.004002';
+$App::bmkpasswd::VERSION = '2.005001';
 use strictures 1;
 use Carp;
 use Try::Tiny;
@@ -191,9 +191,10 @@ sub _const_t_eq {
   ## Constant time comparison is probably overrated for comparing
   ## hashed passwords ... but hey, why not?
   my ($first, $second) = @_;
+  return unless length $first == length $second;
   my ($n, $unequal) = 0;
   no warnings 'substr';
-  while ($n < length $first) {
+  while ($n <= length $first) {
     my $schr = substr($second, $n, 1);
     ++$unequal
       if substr($first, $n, 1) ne (defined $schr ? $schr : '');
@@ -251,9 +252,10 @@ App::bmkpasswd - bcrypt-capable mkpasswd(1) and exported helpers
 
   bmkpasswd --help
   
-  # Generate bcrypted passwords
-  # Defaults to work cost factor '08':
+  # Generate bcrypted passwords:
   bmkpasswd
+
+  # Defaults to work cost factor '08':
   bmkpasswd --workcost='06'
 
   # SHA requires Crypt::Passwd::XS or a recent libc:
@@ -267,7 +269,7 @@ App::bmkpasswd - bcrypt-capable mkpasswd(1) and exported helpers
 
 =head1 DESCRIPTION
 
-B<App::bmkpasswd> is a simple bcrypt-enabled mkpasswd. 
+B<App::bmkpasswd> is a bcrypt-enabled C<mkpasswd> implementation.
 
 Helper functions are also exported for use in other applications; see
 L</EXPORTED>.
@@ -278,20 +280,21 @@ See C<bmkpasswd --help> for command-line usage information.
 
 Uses L<Crypt::Eksblowfish::Bcrypt> for bcrypted passwords.
 
-Bcrypt comes with a configurable work-cost factor; that allows hash generation 
-to become configurably slower as computers get faster, thereby 
+Bcrypt leverages a work-cost factor allowing hash generation
+to become configurably slower as computers get faster, thereby
 impeding brute-force hash generation attempts.
-
-See L<http://codahale.com/how-to-safely-store-a-password/> for more 
+See L<http://codahale.com/how-to-safely-store-a-password/> for more
 on why you ought to be using bcrypt or similar "adaptive" techniques.
 
-B<SHA-256> and B<SHA-512> are supported if available. You'll need 
-either L<Crypt::Passwd::XS> or a system crypt() that can handle SHA
-(such as glibc-2.7+ or modern FreeBSD builds).
+B<SHA-256> and B<SHA-512> are supported if available. SHA support requires
+either L<Crypt::Passwd::XS> or a system crypt() that can handle SHA (such as
+glibc-2.7+ or modern FreeBSD builds).
 
-Uses L<Bytes::Random::Secure> to generate random salts. For the paranoid,
-constant time comparison is used when comparing hashes; strongly-random salts
-can also be enabled (see L</mkpasswd>).
+Uses L<Bytes::Random::Secure> to generate random salts. Strongly-random salts
+can also be enabled; see L</mkpasswd>.
+
+For added security in public-facing applications, constant time comparison is
+used when comparing hashes.
 
 =head1 EXPORTED
 
@@ -321,6 +324,8 @@ Compare a password against a hash.
 B<passwdcmp> will return the hash if it is a match; otherwise, an empty list
 is returned.
 
+Uses constant time comparison to help mitigate against timing attacks.
+
 =head2 mkpasswd_available
 
   my @available = mkpasswd_available;
